@@ -483,11 +483,24 @@ impl<'a> VisitMut for Resolver<'a> {
     /// Handle body of the arrow functions
     fn visit_mut_block_stmt_or_expr(&mut self, node: &mut BlockStmtOrExpr) {
         match node {
-            BlockStmtOrExpr::BlockStmt(block) => block.visit_mut_children_with(self).into(),
-            BlockStmtOrExpr::Expr(e) => e.visit_mut_with(self).into(),
+            BlockStmtOrExpr::BlockStmt(block) => block.visit_mut_children_with(self),
+            BlockStmtOrExpr::Expr(e) => e.visit_mut_with(self),
         }
     }
 
+    fn visit_mut_switch_stmt(&mut self, s: &mut SwitchStmt) {
+        s.discriminant.visit_mut_with(self);
+
+        let child_mark = Mark::fresh(Mark::root());
+
+        let mut child_folder = Resolver::new(
+            Scope::new(ScopeKind::Block, child_mark, Some(&self.current)),
+            self.handle_types,
+        );
+
+        s.cases.visit_mut_with(&mut child_folder);
+    }
+
     fn visit_mut_catch_clause(&mut self, c: &mut CatchClause) {
         let child_mark = Mark::fresh(Mark::root());
 
@@ -753,7 +766,7 @@ impl<'a> VisitMut for Resolver<'a> {
                     return;
                 }
 
-                if let Some(mark) = self.mark_for_ref(&sym) {
+                if let Some(mark) = self.mark_for_ref(sym) {
                     let span = span.apply_mark(mark);
 
                     if cfg!(debug_assertions) && LOG {
@@ -823,17 +836,6 @@ impl<'a> VisitMut for Resolver<'a> {
         }
     }
 
-    fn visit_mut_super_prop_expr(&mut self, e: &mut SuperPropExpr) {
-        if let SuperProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
-    // TODO: How should I handle this?
-    typed!(visit_mut_ts_namespace_export_decl, TsNamespaceExportDecl);
-
-    track_ident_mut!();
-
     fn visit_mut_method_prop(&mut self, m: &mut MethodProp) {
         m.key.visit_mut_with(self);
 
@@ -850,6 +852,11 @@ impl<'a> VisitMut for Resolver<'a> {
         };
     }
 
+    // TODO: How should I handle this?
+    typed!(visit_mut_ts_namespace_export_decl, TsNamespaceExportDecl);
+
+    track_ident_mut!();
+
     fn visit_mut_module_items(&mut self, stmts: &mut Vec<ModuleItem>) {
         if !self.in_ts_module && self.current.kind != ScopeKind::Fn {
             return stmts.visit_mut_children_with(self);
@@ -965,6 +972,12 @@ impl<'a> VisitMut for Resolver<'a> {
         stmts.visit_mut_children_with(self)
     }
 
+    fn visit_mut_super_prop_expr(&mut self, e: &mut SuperPropExpr) {
+        if let SuperProp::Computed(c) = &mut e.prop {
+            c.visit_mut_with(self);
+        }
+    }
+
     fn visit_mut_ts_as_expr(&mut self, n: &mut TsAsExpr) {
         if self.handle_types {
             n.type_ann.visit_mut_with(self);
@@ -1341,6 +1354,15 @@ impl VisitMut for Hoister<'_, '_> {
         self.in_block = old_in_block;
     }
 
+    fn visit_mut_switch_stmt(&mut self, s: &mut SwitchStmt) {
+        s.discriminant.visit_mut_with(self);
+
+        let old_in_block = self.in_block;
+        self.in_block = true;
+        s.cases.visit_mut_with(self);
+        self.in_block = old_in_block;
+    }
+
     #[inline]
     fn visit_mut_catch_clause(&mut self, c: &mut CatchClause) {
         let params: Vec<Id> = find_ids(&c.param);
